Module core

Module core 

Re-exports

pub use errors::GitSheetsError;
pub use errors::Result;

Modules

errors

Structs

Dependency
A dependency represents a reference to another table or file
GitSheetsRepo
A git-sheets repository
Snapshot
A snapshot represents the complete state of a table at a point in time
Table
A table is just headers + rows, nothing fancy
TableHashes
Hashes for verifying table integrity