Re-exports
pub use errors::GitSheetsError;pub use errors::Result;
Modules
Structs
- Dependency
- A dependency represents a reference to another table or file
- GitSheets
Repo - A git-sheets repository
- Snapshot
- A snapshot represents the complete state of a table at a point in time
- Table
- A table is just headers + rows, nothing fancy
- Table
Hashes - Hashes for verifying table integrity